@@ -27,7 +27,7 @@ BEGIN {
 }
 
 
-$VERSION = '1.16_01';
+$VERSION = '1.18_01';
 @ISA = ();
 
 $MATCH_SUPERS = 1;
@@ -439,6 +439,7 @@ sub _try_use {   # Basically a wrapper around "require Modulename"
 
     my $module = $_[0];   # ASSUME sane module name!
     { no strict 'refs';
+        no warnings 'once';
         return($tried{$module} = 1)
         if %{$module . '::Lexicon'} or @{$module . '::ISA'};
         # weird case: we never use'd it, but there it is!
@@ -787,7 +788,7 @@ sub _die_pointing {
             # tabs screw everything up!
             $pointy = substr($_[0],0,$pos);
             $pointy =~ tr/\t //cd;
-            # make everything into whitespace, but preseving tabs
+            # make everything into whitespace, but preserving tabs
             $pointy .= "^=== near there\n";
         }
     }
